# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-12 09:24
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Review',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField(blank=True, null=True, verbose_name='Content ID')),
                ('active', models.BooleanField(default=False, verbose_name='Active')),
                ('user_name', models.CharField(blank=True, max_length=50, verbose_name='Name')),
                ('user_email', models.EmailField(blank=True, max_length=254, verbose_name='E-mail')),
                ('comment', models.TextField(blank=True, verbose_name='Comment')),
                ('score', models.FloatField(choices=[(1, '*'), (2, '**'), (3, '***'), (4, '****'), (5, '*****')], default=3.0, verbose_name='Score')),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
                ('ip_address', models.GenericIPAddressField(blank=True, null=True, verbose_name='IP address')),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='content_type_set_for_review', to='contenttypes.ContentType', verbose_name='Content type')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='review_comments', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
        ),
    ]
